@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from split_settings.tools import optional, include
+from split_settings.tools import include, optional
 
 include(
     # Components:
@@ -19,5 +19,5 @@ include(
     optional('components/missing_file.py'),
 
     # Scope:
-    scope=globals(),
+    scope=globals(),  # noqa: WPS421
 )
