@@ -1,4 +1,6 @@
-DATABASES = {
+# -*- coding: utf-8 -*-
+
+DATABASES = {  # noqa: WPS407
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
         'NAME': 'test.db',
