@@ -1,9 +1,6 @@
-# A sample logging configuration. The only tangible logging
-# performed by this configuration is to send an email to
-# the site admins on every HTTP 500 error when DEBUG=False.
-# See http://docs.djangoproject.com/en/dev/topics/logging for
-# more details on how to customize your logging configuration.
-LOGGING = {
+# -*- coding: utf-8 -*-
+
+LOGGING = {  # noqa: WPS407
     'version': 1,
     'disable_existing_loggers': False,
     'filters': {
